OC.L10N.register(
    "external",
    {
    "Please enter valid urls - they have to start with either http://, https:// or /" : "Proszę wprowadzić poprawne adresy - muszą zaczynać się od http://, https:// lub /",
    "External sites saved." : "Zewnętrzne strony zostały zapisane.",
    "External Sites" : "Zewnętrzne strony",
    "Please note that some browsers will block displaying of sites via http if you are running https." : "Zauważ, że niektóre przeglądarki będą blokować wyświetlanie stron przez http, jeśli używasz https.",
    "Furthermore please note that many sites these days disallow iframing due to security reasons." : "Ponadto należy pamiętać, że wiele stron w dzisiejszych czasach zabrania używanie iframe ze względów bezpieczeństwa.",
    "We highly recommend to test the configured sites below properly." : "Wysoce zalecane jest przetestowanie skonfigurowanych poniżej stron.",
    "Name" : "Nazwa",
    "URL" : "URL",
    "Select an icon" : "Wybierz ikonę",
    "Remove site" : "Usuń stronę",
    "Add" : "Dodaj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
